Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sbin/swapctl add a -D line to usage().



details:   https://anonhg.NetBSD.org/src/rev/f776d290baf4
branches:  trunk
changeset: 472232:f776d290baf4
user:      mrg <mrg%NetBSD.org@localhost>
date:      Mon Apr 26 01:02:25 1999 +0000

description:
add a -D line to usage().

diffstat:

 sbin/swapctl/swapctl.c |  13 +++++++------
 1 files changed, 7 insertions(+), 6 deletions(-)

diffs (52 lines):

diff -r 57a5aa5c1133 -r f776d290baf4 sbin/swapctl/swapctl.c
--- a/sbin/swapctl/swapctl.c    Mon Apr 26 00:29:15 1999 +0000
+++ b/sbin/swapctl/swapctl.c    Mon Apr 26 01:02:25 1999 +0000
@@ -1,7 +1,7 @@
-/*     $NetBSD: swapctl.c,v 1.10 1999/02/23 17:00:53 mrg Exp $ */
+/*     $NetBSD: swapctl.c,v 1.11 1999/04/26 01:02:25 mrg Exp $ */
 
 /*
- * Copyright (c) 1996, 1997 Matthew R. Green
+ * Copyright (c) 1996, 1997, 1999 Matthew R. Green
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -109,7 +109,7 @@
 
 static void change_priority __P((const char *));
 static void add_swap __P((const char *));
-static void del_swap __P((const char *));
+static void delete_swap __P((const char *));
 static void set_dumpdev __P((const char *));
        int  main __P((int, char *[]));
 static void do_fstab __P((void));
@@ -246,7 +246,7 @@
                break;
 
        case CMD_d:
-               del_swap(argv[0]);
+               delete_swap(argv[0]);
                break;
 
        case CMD_A:
@@ -351,10 +351,10 @@
 }
 
 /*
  * del_swap:  remove the pathname to the list of swap devices.
  */
 void
-del_swap(path)
+delete_swap(path)
        const char *path;
 {
 
@@ -481,6 +481,7 @@
 
        fprintf(stderr, "usage: %s -A [-p priority] [-t blk|noblk]\n",
            __progname);
+       fprintf(stderr, "       %s -D dumppath\n", __progname);
        fprintf(stderr, "       %s -a [-p priority] path\n", __progname);
        fprintf(stderr, "       %s -c -p priority path\n", __progname);
        fprintf(stderr, "       %s -d path\n", __progname);
@@ -351,10 +351,10 @@
 
 /*
- * del_swap:  remove the pathname to the list of swap devices.
+ * delete_swap:  remove the pathname to the list of swap devices.
  */
 void



Home | Main Index | Thread Index | Old Index